import {Refine, Authenticated} from '@refinedev/core'
import {DevtoolsPanel, DevtoolsProvider} from '@refinedev/devtools'
import {RefineKbar, RefineKbarProvider} from '@refinedev/kbar'

import {ErrorComponent, useNotificationProvider, RefineSnackbarProvider, ThemedLayoutV2} from '@refinedev/mui'

import dataProvider from '@refinedev/simple-rest'
import CssBaseline from '@mui/material/CssBaseline'
import GlobalStyles from '@mui/material/GlobalStyles'
import {BrowserRouter, Route, Routes, Outlet} from 'react-router'
import routerBindings, {NavigateToResource, CatchAllNavigate, UnsavedChangesNotifier, DocumentTitleHandler} from '@refinedev/react-router'
import {ColorModeContextProvider} from './contexts/color-mode'
import {Header} from './components/header'
import {Login} from './pages/login'
import {Register} from './pages/register'
import {ForgotPassword} from './pages/forgotPassword'
import {authProvider} from './authProvider'

// import {BlogPostList, BlogPostCreate, BlogPostEdit, BlogPostShow} from './pages/blog-posts'
// import {CategoryList, CategoryCreate, CategoryEdit, CategoryShow} from './pages/categories'

import {CountryList, CountryCreate, CountryEdit} from './pages/country'
import {CityList, CityCreate, CityEdit} from './pages/city'
import {CarrierList, CarrierCreate, CarrierEdit} from './pages/carrier'
import {MediaList, MediaCreate, MediaEdit, MediaShow} from './pages/media'
import {ArticleList, ArticleCreate, ArticleEdit} from './pages/article'

import {CountryIcon, CityIcon, CarrierIcon, MediaIcon, ArticleIcon} from './components/ui/Icons'

function App() {
  return (
    <BrowserRouter>
      <RefineKbarProvider>
        <ColorModeContextProvider>
          <CssBaseline />
          <GlobalStyles styles={{html: {WebkitFontSmoothing: 'auto'}}} />
          <RefineSnackbarProvider>
            <DevtoolsProvider>
              <Refine
                dataProvider={dataProvider('https://wn.krbl.ru')}
                notificationProvider={useNotificationProvider}
                routerProvider={routerBindings}
                authProvider={authProvider}
                resources={[
                  {
                    name: 'country',
                    list: '/country',
                    create: '/country/create',
                    edit: '/country/edit/:id',
                    meta: {
                      canDelete: true,
                      label: 'Страны',
                      icon: <CountryIcon />,
                    },
                  },
                  {
                    name: 'city',
                    list: '/city',
                    create: '/city/create',
                    edit: '/city/edit/:id',
                    meta: {
                      canDelete: true,
                      label: 'Города',
                      icon: <CityIcon />,
                    },
                  },
                  {
                    name: 'carrier',
                    list: '/carrier',
                    create: '/carrier/create',
                    edit: '/carrier/edit/:id',
                    meta: {
                      canDelete: true,
                      label: 'Перевозчики',
                      icon: <CarrierIcon />,
                    },
                  },
                  {
                    name: 'media',
                    list: '/media',
                    create: '/media/create',
                    edit: '/media/edit/:id',
                    show: '/media/show/:id',
                    meta: {
                      canDelete: true,
                      label: 'Медиа',
                      icon: <MediaIcon />,
                    },
                  },
                  {
                    name: 'article',
                    list: '/article',
                    create: '/article/create',
                    edit: '/article/edit/:id',
                    // добавить SHOW для article->media (https://wn.krbl.ru/article/2/media)
                    meta: {
                      canDelete: true,
                      label: 'Статьи',
                      icon: <ArticleIcon />,
                    },
                  },
                ]}
                options={{
                  syncWithLocation: true,
                  warnWhenUnsavedChanges: true,
                  useNewQueryKeys: true,
                  projectId: 'Wv044J-t53S3s-PcbJGe',
                }}
              >
                <Routes>
                  <Route
                    element={
                      <Authenticated key="authenticated-inner" fallback={<CatchAllNavigate to="/login" />}>
                        <ThemedLayoutV2 Header={Header}>
                          <Outlet />
                        </ThemedLayoutV2>
                      </Authenticated>
                    }
                  >
                    <Route index element={<NavigateToResource resource="country" />} />

                    <Route path="/country">
                      <Route index element={<CountryList />} />
                      <Route path="create" element={<CountryCreate />} />
                      <Route path="edit/:name" element={<CountryEdit />} />
                    </Route>

                    <Route path="/city">
                      <Route index element={<CityList />} />
                      <Route path="create" element={<CityCreate />} />
                      <Route path="edit/:id" element={<CityEdit />} />
                    </Route>

                    <Route path="/carrier">
                      <Route index element={<CarrierList />} />
                      <Route path="create" element={<CarrierCreate />} />
                      <Route path="edit/:id" element={<CarrierEdit />} />
                    </Route>

                    <Route path="/media">
                      <Route index element={<MediaList />} />
                      <Route path="create" element={<MediaCreate />} />
                      <Route path="edit/:id" element={<MediaEdit />} />
                      <Route path="show/:id" element={<MediaShow />} />
                    </Route>

                    <Route path="/article">
                      <Route index element={<ArticleList />} />
                      <Route path="create" element={<ArticleCreate />} />
                      <Route path="edit/:id" element={<ArticleEdit />} />
                    </Route>

                    <Route path="*" element={<ErrorComponent />} />
                  </Route>
                  <Route
                    element={
                      <Authenticated key="authenticated-outer" fallback={<Outlet />}>
                        <NavigateToResource />
                      </Authenticated>
                    }
                  >
                    <Route path="/login" element={<Login />} />
                    <Route path="/register" element={<Register />} />
                    <Route path="/forgot-password" element={<ForgotPassword />} />
                  </Route>
                </Routes>

                <RefineKbar />
                <UnsavedChangesNotifier />
                <DocumentTitleHandler />
              </Refine>
              <DevtoolsPanel />
            </DevtoolsProvider>
          </RefineSnackbarProvider>
        </ColorModeContextProvider>
      </RefineKbarProvider>
    </BrowserRouter>
  )
}

export default App
